@@ -2,11 +2,11 @@
 //
 // RQuantLib -- R interface to the QuantLib libraries
 //
-// Copyright (C) 2002 - 2011  Dirk Eddelbuettel 
+// Copyright (C) 2002 - 2012  Dirk Eddelbuettel 
 // Copyright (C) 2005 - 2006  Dominick Samperi
-// Copyright (C) 2009 - 2011  Dirk Eddelbuettel and Khanh Nguyen
+// Copyright (C) 2009 - 2012  Dirk Eddelbuettel and Khanh Nguyen
 //
-// $Id: utils.cpp 322 2011-09-10 15:09:06Z edd $
+// $Id$
 //
 // This file is part of the RQuantLib library for GNU R.
 // It is made available under the terms of the GNU General Public
@@ -126,11 +126,9 @@ boost::shared_ptr<QuantLib::YieldTermStructure> buildTermStructure(SEXP params,
         //double dt = rparam.getDoubleValue("dt");
         
         std::string interpWhat, interpHow;
-        bool flatQuotes = true;
         if (firstQuoteName.compare("flat") != 0) { // Get interpolation method (not needed for "flat" case)
             interpWhat = Rcpp::as<std::string>(rparam["interpWhat"]);
             interpHow  = Rcpp::as<std::string>(rparam["interpHow"]);
-            flatQuotes = false;
         }
         
         // initialise from the singleton instance
@@ -297,9 +295,11 @@ makeProcess(const boost::shared_ptr<QuantLib::Quote>& u,
 //     return(d.getJDN() - RcppDate::Jan1970Offset + RcppDate::QLtoJan1970Offset);
 // }
 
+static const unsigned int QLtoJan1970Offset = 25569;  	// Offset between R / Unix epoch 
+
 // R and Rcpp::Date use the same 'days since epoch' representation; QL uses Excel style
 int dateFromR(const Rcpp::Date &d) {
-    return(d.getDate() + Rcpp::Date::QLtoJan1970Offset);
+    return(d.getDate() + QLtoJan1970Offset);
 }
 
 QuantLib::DayCounter getDayCounter(const double n){
